@@ -18,8 +18,8 @@
 import sys
 import re
 
-from arjuna.tpi.enums import *
-from arjuna.core.enums import *
+from arjuna.tpi.constant import *
+from arjuna.core.constant import *
 
 def ustr(input):
     return (str(input)).upper()
